src.MEDS\_tabular\_automl.generate\_static\_features
====================================================

.. automodule:: src.MEDS_tabular_automl.generate_static_features







   .. rubric:: Functions

   .. autosummary::

      convert_to_matrix
      get_flat_static_rep
      get_sparse_static_rep
      summarize_static_measurements
